@@ -81,7 +81,6 @@ class UI(DisplayableContainer):
             self.setup()
             self.win.addstr("loading...")
             self.win.refresh()
-            curses.setupterm()
             self._draw_title = curses.tigetflag('hs') # has_status_line
         self.update_size()
         self.is_on = True
@@ -311,6 +310,8 @@ class UI(DisplayableContainer):
         """Finalize every object in container and refresh the window"""
         DisplayableContainer.finalize(self)
         self.win.refresh()
+        if self.pager.visible:
+            self.pager.draw_image()
 
     def close_pager(self):
         if self.console.visible:
@@ -377,3 +378,9 @@ class UI(DisplayableContainer):
 
     def hint(self, text=None):
         self.status.hint = text
+
+    def get_pager(self):
+        if self.browser.pager.visible:
+            return self.browser.pager
+        else:
+            return self.pager
